<?php
namespace ElementorHelloWorld;

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.2.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		wp_register_script( 'elementor-hello-world', plugins_url( '/assets/js/hello-world.js', __FILE__ ), [ 'jquery' ], false, true );
        wp_register_script('jws-query-control', JWS_URI_PATH . '/inc/widget_elementor/control/js/jquery.js', array(), '', true);
	}
    private function include_control_files() {
        require_once (JWS_ABS_PATH . '/inc/widget_elementor/control/query.php');

    }
    public function register_controls($controls_manager) {
        // Its is now safe to include Control files
        $this->include_control_files();
        $controls_manager->register( new \JwsElementor\Control\Query());
    }
    
	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/test.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/hello-world.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-post-archive.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-slide-post.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-logo.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-case_study.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-post-related.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-price-table.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/inline-editing.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-product-details.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-product-related.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-product-archive.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-product-featured.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-team.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-single-team.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-team-archive.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-services.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-testimonial/jws-testimonial.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-menu.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-search.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-account.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-progress.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws_off_canvas.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws_tab.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/svg-convert.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-timeline.php' );
		require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-breadcrumbs.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-menu-listing.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-video-popup.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-login-form/jws-login-form.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/Twitter.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-button.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-icon-box.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/jws-project.php' );
        require_once( JWS_ABS_PATH. '/inc/widget_elementor/widgets/jws-custom/contact_form7.php' );
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();
        
		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\Test() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\Hello_World() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JwsPostArchive() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JwsSlidePost() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JwsSVG_Convert() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Jws_case_study() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JwsLogo() );
    	\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Progress() );
    	\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Account() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Search() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\PostRelated() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\Inline_Editing() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\ProductDetails() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\ProductRelated() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\ProductArchive() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\ProductFeatured() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JwsTeams() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JwsTeamsArchive() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JwsServices() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Price_Table() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Jws_Testimonial() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Nav_Menu() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Offcanvas() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Jws_tab() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Timeline() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Jws_Breakscrumbs() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Menu_Liting() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Video_popup() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Login_form() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Twitter() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Button() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\JWS_Icon_Box() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Projects() );
        \Elementor\Plugin::instance()->widgets_manager->register( new Widgets\JwsCustom\Jws_cf7() );
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {
		
        include_once ('shade_animation.php');
        include_once ('particles.php');
		// Register widget scripts

        add_action('elementor/editor/before_enqueue_scripts', [$this, 'widget_scripts']);
       // Register controls
        add_action('elementor/controls/controls_registered', [$this, 'register_controls']);
		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();

add_action( 'elementor/element/accordion/section_title_style/before_section_end', function( $element, $args ) {

    $element->add_control(
			'spacing',
			[
				'label' =>  esc_html__( 'Spacing', 'ailab' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 2,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 10,
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
	);
     $element->add_control(
			'radius',
			[
				'label' =>  esc_html__( 'Border Radius', 'ailab' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-accordion-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
	   );
    $element->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'jws_ac_border',
				'label' =>  esc_html__( 'Border', 'ailab' ),
				'selector' => '{{WRAPPER}} .elementor-accordion .elementor-accordion-item',
			]
		);
        $element->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'jws_ac_shadow1',
				'label' =>  esc_html__( 'Box Shadow', 'ailab' ),
				'selector' => 'body {{WRAPPER}} .elementor-accordion .elementor-accordion-item',
			]
		);

}, 10, 2 );

add_action( 'elementor/element/accordion/section_toggle_style_icon/before_section_end', function( $element, $args ) {

        $element->add_control(
			'icon_size',
			[
				'label' =>  esc_html__( 'Icon Size', 'ailab' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 10,
				],
				'selectors' => [
					'{{WRAPPER}} .elementor-tab-title .elementor-accordion-icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);
         $element->add_control(
			'icon_padding',
			[
				'label' =>  esc_html__( 'Padding', 'ailab' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .elementor-tab-title .elementor-accordion-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
	   );
  
	
}, 10, 2 );

add_action( 'elementor/element/accordion/section_toggle_style_title/before_section_end', function( $element, $args ) {

         $element->add_control(
			'toggle_radius',
			[
				'label' =>  esc_html__( 'Boder Radius', 'ailab' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
	   );
       $element->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'toggle_border',
				'label' =>  esc_html__( 'Border', 'ailab' ),
				'selector' => 'body {{WRAPPER}} .elementor-accordion .elementor-accordion-item .elementor-tab-title',
			]
		);
        $element->add_control(
			'toggle_background_active',
			[
				'label' =>  esc_html__( 'Background Active', 'ailab' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .elementor-accordion .elementor-tab-title.elementor-active' => 'background-color: {{VALUE}}',
				],
			]
	   );
        $element->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'toggle_border_active',
				'label' =>  esc_html__( 'Border Active', 'ailab' ),
				'selector' => 'body {{WRAPPER}} .elementor-accordion .elementor-accordion-item .elementor-tab-title.elementor-active',
			]
		);  
        $element->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'toggle_box_shadow1',
				'label' =>  esc_html__( 'Box Shadow', 'ailab' ),
				'selector' => 'body {{WRAPPER}} .elementor-accordion .elementor-accordion-item .elementor-tab-title',
			]
		);
        $element->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'toggle_box_shadow',
				'label' =>  esc_html__( 'Box Shadow Active', 'ailab' ),
				'selector' => 'body {{WRAPPER}} .elementor-accordion .elementor-accordion-item .elementor-tab-title.elementor-active',
			]
		);
	
}, 10, 2 );


add_action( 'elementor/element/accordion/section_toggle_style_content/before_section_end', function( $element, $args ) {

        $element->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'toggle_conten_border',
				'label' =>  esc_html__( 'Border', 'ailab' ),
				'selector' => 'body {{WRAPPER}} .elementor-accordion .elementor-tab-content',
			]
		);
         $element->add_control(
			'toggle_conten_margin',
			[
				'label' =>  esc_html__( 'Margin', 'ailab' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'body {{WRAPPER}} .elementor-accordion .elementor-tab-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
	   );
	
}, 10, 2 );